changeset 749:b8c49473be38

typo
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 09 Apr 2014 09:45:36 +0200
parents de9763f63510
children 4afad8cb94fd
files Core/HttpServer/MongooseServer.cpp
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/Core/HttpServer/MongooseServer.cpp	Wed Apr 09 09:31:38 2014 +0200
+++ b/Core/HttpServer/MongooseServer.cpp	Wed Apr 09 09:45:36 2014 +0200
@@ -756,12 +756,12 @@
     filter_ = NULL;
 
 #if ORTHANC_SSL_ENABLED == 1
     // Check for the Heartbeat exploit
     // https://en.wikipedia.org/wiki/OpenSSL#Heartbleed_bug
     if (OPENSSL_VERSION_NUMBER <  0x1000107fL  /* openssl-1.0.1g */ &&
         OPENSSL_VERSION_NUMBER >= 0x1000100fL  /* openssl-1.0.1 */) 
     {
-      LOG(WARNING) << "This version of OpenSSL can be affected by the Heartbeat exploit";
+      LOG(WARNING) << "This version of OpenSSL is vulnerable to the Heartbleed exploit";
     }
 #endif
   }
@@ -756,12 +756,12 @@
 
 #if ORTHANC_SSL_ENABLED == 1
-    // Check for the Heartbeat exploit
+    // Check for the Heartbleed exploit
     // https://en.wikipedia.org/wiki/OpenSSL#Heartbleed_bug
     if (OPENSSL_VERSION_NUMBER <  0x1000107fL  /* openssl-1.0.1g */ &&